<?php

namespace Drupal\trash\EntityQuery\Workspaces;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\Query\QueryBase;
use Drupal\workspaces\EntityQuery\QueryFactory as WorkspacesQueryFactory;

/**
 * Overrides the core workspaces query factory.
 */
class QueryFactory extends WorkspacesQueryFactory {

  /**
   * The workspace information service.
   *
   * @var \Drupal\workspaces\WorkspaceInformationInterface
   */
  protected $workspaceInfo;

  /**
   * Constructs a QueryFactory object.
   */
  public function __construct(...$args) {
    parent::__construct(...$args);

    // Add forward compatibility with a core patch.
    // @see https://www.drupal.org/project/drupal/issues/3101671
    if (\Drupal::getContainer()->has('workspaces.information')) {
      $this->workspaceInfo = \Drupal::service('workspaces.information');
    }
  }

  /**
   * {@inheritdoc}
   */
  public function get(EntityTypeInterface $entity_type, $conjunction) {
    $class = QueryBase::getClass($this->namespaces, 'Query');
    if ($this->workspaceInfo) {
      return new $class($entity_type, $conjunction, $this->connection, $this->namespaces, $this->workspaceManager, $this->workspaceInfo);
    }
    return new $class($entity_type, $conjunction, $this->connection, $this->namespaces, $this->workspaceManager);
  }

  /**
   * {@inheritdoc}
   */
  public function getAggregate(EntityTypeInterface $entity_type, $conjunction) {
    $class = QueryBase::getClass($this->namespaces, 'QueryAggregate');
    if ($this->workspaceInfo) {
      return new $class($entity_type, $conjunction, $this->connection, $this->namespaces, $this->workspaceManager, $this->workspaceInfo);
    }
    return new $class($entity_type, $conjunction, $this->connection, $this->namespaces, $this->workspaceManager);
  }

}
