<?php

namespace Drupal\trash\EventSubscriber;

use Drupal\Core\Update\UpdateKernel;
use Drupal\trash\TrashManagerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\KernelEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Listens to the REQUEST event for setting the ignore context on updates.
 */
class TrashUpdatesSubscriber implements EventSubscriberInterface {

  /**
   * Constructs the TrashUpdatesSubscriber.
   *
   * @param \Drupal\trash\TrashManagerInterface $trashManager
   *   The trash manager.
   */
  public function __construct(protected TrashManagerInterface $trashManager) {}

  /**
   * Sets the trash context to ignore.
   *
   * This is required so upgrades affecting entities will affect all entities,
   * no matter if they have been trashed.
   *
   * @param \Symfony\Component\HttpKernel\Event\KernelEvent $event
   *   The KernelEvent to process.
   */
  public function onRequest(KernelEvent $event) {
    if ($event->getKernel() instanceof UpdateKernel) {
      $this->trashManager->setTrashContext('ignore');
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::REQUEST][] = ['onRequest'];
    return $events;
  }

}
