<?php

namespace Drupal\trash;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;
use Drupal\trash\EntityQuery\Sql\QueryFactory as SqlQueryFactory;
use Drupal\trash\EntityQuery\Workspaces\QueryFactory as WorkspacesQueryFactory;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Alters container services.
 */
class TrashServiceProvider extends ServiceProviderBase {

  /**
   * {@inheritdoc}
   */
  public function alter(ContainerBuilder $container): void {
    // @todo Revert to decorating the entity type manager when we can require
    //   Drupal 10.
    if ($container->hasDefinition('entity_type.manager')) {
      $container->getDefinition('entity_type.manager')
        ->setClass(TrashEntityTypeManager::class);
    }

    // We cannot use the module handler as the container is not yet compiled.
    // @see \Drupal\Core\DrupalKernel::compileContainer()
    $modules = $container->getParameter('container.modules');

    if (isset($modules['workspaces'])) {
      $container->getDefinition('entity.query.sql')
        ->setClass(WorkspacesQueryFactory::class)
        ->addArgument(new Reference('workspaces.manager'));

      // Add forward compatibility with a core patch.
      // @see https://www.drupal.org/project/drupal/issues/3101671
      if ($container->hasDefinition('workspaces.information')) {
        $container->getDefinition('entity.query.sql')
          ->addArgument(new Reference('workspaces.information'));
      }

      $container->removeDefinition('workspaces.entity.query.sql');
    }
    else {
      $container->getDefinition('entity.query.sql')
        ->setClass(SqlQueryFactory::class);
    }

    if ($container->hasDefinition('workspaces.information')) {
      $container->register('trash.workspaces.information', TrashWorkspaceInformation::class)
        ->setPublic(FALSE)
        ->setDecoratedService('workspaces.information', NULL, 100)
        ->addArgument(new Reference('trash.workspaces.information.inner'))
        ->addArgument(new Reference('trash.manager'));
    }

    if ($container->hasDefinition('workspaces.manager')) {
      $container->register('trash.workspaces.manager', TrashWorkspaceManager::class)
        ->setPublic(FALSE)
        ->setDecoratedService('workspaces.manager', NULL, 100)
        ->addArgument(new Reference('trash.workspaces.manager.inner'))
        ->addArgument(new Reference('trash.manager'));
    }
  }

}
